@@ -15,11 +15,6 @@ if RANDOMIZE_DISPLAY_NR:
 
 MIN_DISPLAY_NR = 1000
         
-def listdir(f, pattern):
-    names = os.listdir(self)
-    names = fnmatch.filter(names, pattern)
-    return [f / child for child in names]
-
 class AbstractDisplay(EasyProcess):
     '''
     Common parent for Xvfb and Xephyr
